@@ -774,6 +774,7 @@ class GradescopeClient:
         {
             autograder_score,
             max_score,
+            output,
             tests : [
                 {
                     name,
@@ -798,10 +799,15 @@ class GradescopeClient:
         tests = []
         total_points_string = soup.find_all("div", class_="submissionOutlineHeader--totalPoints")[0].text
         score, max_score = map(str.strip, total_points_string.split("/"))
+        output = None
+        output_div = soup.find_all("div", class_="autograderResults--topLevelOutput")
+        if output_div:
+            output = output_div[0].find("div").text
         r = {
             "tests": tests,
             "score": score,
-            "max_score": max_score
+            "max_score": max_score,
+            "output": output
         }
         score_re = re.compile(r"\((\d+(?:.\d+))\s*\/\s*(\d+(?:.\d+))\)")
         for i, item in enumerate(header):
